homescreenpluginsrv/hspsmanager/inc/hspsrominstaller.h
branchRCL_3
changeset 27 2c7f27287390
parent 22 1b207dd38b72
--- a/homescreenpluginsrv/hspsmanager/inc/hspsrominstaller.h	Mon Jun 21 16:00:38 2010 +0300
+++ b/homescreenpluginsrv/hspsmanager/inc/hspsrominstaller.h	Thu Jul 15 18:59:18 2010 +0300
@@ -151,15 +151,26 @@
         void ConstructL();           
                         
         /**         
          * Retrieves manifest files from all internal drives in 
          * \\private\200159C0\install\ paths.
          * @since S60 5.0         
          * @param aFileArray An array of file names
          */
-        void FindInstallationFilesL(  
-                RPointerArray<HBufC>& aFileArray );
+        void FindInstallFilesL(  
+                RPointerArray<HBufC>& aFileArray );        
+        void DoFindInstallFilesL(  
+                RPointerArray<HBufC>& aFileArray,
+                const TDesC& aPath );
         
-        void DoFindInstallationFilesL(  
+        /**         
+         * Retrieves manifest files from all internal drives under the  
+         * \\private\200159C0\import\ path.
+         * @since S60 5.2         
+         * @param aFileArray An array of file names
+         */
+        void FindImportFilesL(
+                RPointerArray<HBufC>& aFileArray );        
+        void DoFindImportFilesL( 
                 RPointerArray<HBufC>& aFileArray,
                 const TDesC& aPath );
@@ -151,15 +151,26 @@
                         
         /**         
-         * Retrieves manifest files from all internal drives in 
-         * \\private\200159C0\install\ paths.
-         * @since S60 5.0         
+         * Retrieves manifest files from all internal drives under the  
+         * \\private\200159C0\install\ path.
+         * @since S60 5.2         
          * @param aFileArray An array of file names
          */